@@ -39,9 +39,7 @@
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
-#include <Lum/Array.h>
 #include <Lum/Boolean.h>
-#include <Lum/ButtonRow.h>
 #include <Lum/Dialog.h>
 #include <Lum/Grid.h>
 #include <Lum/Label.h>
@@ -167,30 +165,33 @@ public:
     for (size_t x=0; x<10; x++) {
       if (x==pos) {
         text=new Lum::Text();
+        text->SetFlex(true,true);
         text->SetText(Lum::Base::NumberToWString((unsigned long)x+1)+L":");
         grid->SetObject(0,x,text);
-        grid->SetObject(1,x,Lum::String::Create(name,10,true,false));
+
+        grid->SetObject(1,x,Lum::String::Create(name,10,true,true));
 
         text=new Lum::Text();
         text->SetAlignment(Lum::Text::left);
-        text->SetFlex(true,false);
+        text->SetFlex(true,true);
         text->SetText(Lum::Base::NumberToWString((unsigned long)score->list[x].time)+L" second(s)");
         grid->SetObject(2,x,text);
       }
       else if (x<score->list.size() && (x+1==pos|| x+2==pos || x==pos+1 || x==pos+2)) {
         text=new Lum::Text();
+        text->SetFlex(true,true);
         text->SetText(Lum::Base::NumberToWString((unsigned long)x+1)+L":");
         grid->SetObject(0,x,text);
 
         text=new Lum::Text();
-        text->SetFlex(true,false);
+        text->SetFlex(true,true);
         text->SetAlignment(Lum::Text::left);
         text->SetText(score->list[x].name);
         grid->SetObject(1,x,text);
 
         text=new Lum::Text();
         text->SetAlignment(Lum::Text::left);
-        text->SetFlex(true,false);
+        text->SetFlex(true,true);
         text->SetText(Lum::Base::NumberToWString((unsigned long)score->list[x].time)+L" second(s)");
         grid->SetObject(2,x,text);
       }
@@ -362,14 +363,13 @@ public:
   Lum::Object* GetContent()
   {
     Lum::Label       *label;
-    Lum::Panel       *panel,*hPanel;
-    Lum::Array       *array;
+    Lum::Panel       *panel,*hPanel,*vPanel;
     Lum::Slider      *slider;
     Lum::TextValue   *textValue;
 
-    panel=Lum::VPanel::Create();
+    panel=Lum::HPanel::Create(true,false);
 
-    label=Lum::Label::Create();
+    label=Lum::Label::Create(true,false);
 
     slider=new Lum::HSlider();
     slider->SetFlex(true,false);
@@ -385,20 +385,9 @@ public:
 
     slider=new Lum::HSlider();
     slider->SetFlex(true,false);
-    slider->SetScale(true);
     slider->SetModel(mines);
     label->AddLabel(L"Mines (in %):",slider);
 
-    array=new Lum::Array();
-    array->SetFlex(true,false);
-    array->SetSpace(true,false);
-    array->SetVerticalCount(1);
-
-    array->Add(Lum::Button::Create(L"_Small",smallAction,true));
-    array->Add(Lum::Button::Create(L"_Medium",mediumAction,true));
-    array->Add(Lum::Button::Create(L"_Big",bigAction,true));
-
-    label->AddLabel(L"Presets:",array);
     label->AddLabel(L"One button mode:",Lum::Boolean::Create(oneButtonMode));
 
     hPanel=Lum::HPanel::Create(true,false);
@@ -413,6 +402,17 @@ public:
     label->AddLabel(L"Theme:",hPanel);
     panel->Add(label);
 
+    panel->AddSpace();
+
+    vPanel=Lum::VPanel::Create(false,true);
+
+    vPanel->Add(Lum::Button::Create(L"_Small",smallAction,true));
+    vPanel->Add(Lum::Button::Create(L"_Medium",mediumAction,true));
+    vPanel->Add(Lum::Button::Create(L"_Big",bigAction,true));
+    vPanel->AddSpace(true);
+
+    panel->Add(vPanel);
+
     return panel;
   }
 
@@ -574,7 +574,8 @@ public:
                                   .SetShortcut(Lum::OS::qualifierControl,L"n"),
                                   newGameAction))
         ->Separator()
-        ->Action(Lum::Def::Action(Lum::Def::Desc(L"_Hiscore..."),hiscoreAction))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(L"_Hiscore"),hiscoreAction)
+                 .SetOpensDialog())
         ->Separator()
         ->ActionQuit(GetClosedAction())
       ->End()
